pub struct Num { /* private fields */ }Expand description
Builder for numeric predicates.
Implementations
Sourceimpl Num
impl Num
Sourcepub fn eq(self, value: f64) -> FilterExpression
pub fn eq(self, value: f64) -> FilterExpression
Matches values equal to the supplied value.
Sourcepub fn ne(self, value: f64) -> FilterExpression
pub fn ne(self, value: f64) -> FilterExpression
Negates values equal to the supplied value.
Sourcepub fn gt(self, value: f64) -> FilterExpression
pub fn gt(self, value: f64) -> FilterExpression
Matches values greater than the supplied value.
Sourcepub fn gte(self, value: f64) -> FilterExpression
pub fn gte(self, value: f64) -> FilterExpression
Matches values greater than or equal to the supplied value.
Sourcepub fn lt(self, value: f64) -> FilterExpression
pub fn lt(self, value: f64) -> FilterExpression
Matches values less than the supplied value.
Sourcepub fn lte(self, value: f64) -> FilterExpression
pub fn lte(self, value: f64) -> FilterExpression
Matches values less than or equal to the supplied value.
Sourcepub fn between(
self,
left: f64,
right: f64,
inclusive: BetweenInclusivity,
) -> FilterExpression
pub fn between( self, left: f64, right: f64, inclusive: BetweenInclusivity, ) -> FilterExpression
Matches values between the supplied bounds.
Sourcepub fn is_missing(self) -> FilterExpression
pub fn is_missing(self) -> FilterExpression
Matches documents where this numeric field is absent.