QueryString

Trait QueryString 

pub trait QueryString {
Show 13 methods // Required method fn to_redis_query(&self) -> String; // Provided methods fn render(&self) -> QueryRender { ... } fn params(&self) -> Vec<QueryParam> { ... } fn return_fields(&self) -> Vec<String> { ... } fn sort_by(&self) -> Option<SortBy> { ... } fn limit(&self) -> Option<QueryLimit> { ... } fn dialect(&self) -> u32 { ... } fn in_order(&self) -> bool { ... } fn no_content(&self) -> bool { ... } fn scorer(&self) -> Option<String> { ... } fn kind(&self) -> QueryKind { ... } fn should_unpack_json(&self) -> bool { ... } fn geofilter(&self) -> Option<GeoFilter> { ... }
}
Trait for query types that can render Redis Search query strings.

Required Methods

fn to_redis_query(&self) -> String

Builds a Redis Search query string.

Provided Methods

fn render(&self) -> QueryRender

Builds the full query render, including search options and params.

fn params(&self) -> Vec<QueryParam>

Query parameters used with Redis PARAMS.

fn return_fields(&self) -> Vec<String>

Return fields requested by the query.

fn sort_by(&self) -> Option<SortBy>

Sort order requested by the query.

fn limit(&self) -> Option<QueryLimit>

Limit clause requested by the query.

fn dialect(&self) -> u32

Query dialect.

fn in_order(&self) -> bool

Whether the query should use INORDER.

fn no_content(&self) -> bool

Whether the query should use NOCONTENT.

fn scorer(&self) -> Option<String>

Optional scorer.

fn kind(&self) -> QueryKind

The processed result shape for this query.

fn should_unpack_json(&self) -> bool

Whether JSON search results should be unpacked into top-level fields when no explicit projection is requested.

fn geofilter(&self) -> Option<GeoFilter>

Optional geo-spatial filter for FT.SEARCH GEOFILTER clause.

Implementations on Foreign Types

Source

impl QueryString for &str

Source

impl QueryString for str

Source

impl QueryString for String

Implementors