pub struct BedrockTextVectorizer { /* private fields */ }Expand description
AWS Bedrock embedding adapter.
Uses the Bedrock Runtime InvokeModel API with SigV4 authentication.
Each text is embedded individually since Bedrock does not support batch
embedding.
Example
use redis_vl::vectorizers::{BedrockConfig, BedrockTextVectorizer, Vectorizer};
let config = BedrockConfig::from_env()?;
let rt = tokio::runtime::Runtime::new().unwrap();
let vectorizer = rt.block_on(BedrockTextVectorizer::new(config))?;Implementations
Sourceimpl BedrockTextVectorizer
impl BedrockTextVectorizer
Sourcepub async fn new(config: BedrockConfig) -> Result<Self>
pub async fn new(config: BedrockConfig) -> Result<Self>
Creates a new Bedrock adapter by building an AWS SDK client from the provided configuration.
This is an async constructor because the AWS SDK credential
resolution is asynchronous.