pub struct HuggingFaceTextVectorizer { /* private fields */ }Expand description
HuggingFace local embedding adapter backed by ONNX Runtime.
Uses the fastembed crate to run embedding models locally. Models are
automatically downloaded from the HuggingFace Hub on first use and cached
on disk.
This vectorizer implements Vectorizer for synchronous embedding
generation. For async use cases, wrap it with
tokio::task::spawn_blocking or use it with the synchronous semantic
extension APIs.
Implementations
Sourceimpl HuggingFaceTextVectorizer
impl HuggingFaceTextVectorizer
Sourcepub fn new(config: HuggingFaceConfig) -> Result<Self>
pub fn new(config: HuggingFaceConfig) -> Result<Self>
Creates a new HuggingFace local vectorizer.
This may download the model from HuggingFace Hub on first invocation.
Errors
Returns an error if the model cannot be loaded.