pub trait QueryString {
Show 13 methods
// Required method
fn to_redis_query(&self) -> String;
// Provided methods
fn render(&self) -> QueryRender { ... }
fn params(&self) -> Vec<QueryParam> { ... }
fn return_fields(&self) -> Vec<String> { ... }
fn sort_by(&self) -> Option<SortBy> { ... }
fn limit(&self) -> Option<QueryLimit> { ... }
fn dialect(&self) -> u32 { ... }
fn in_order(&self) -> bool { ... }
fn no_content(&self) -> bool { ... }
fn scorer(&self) -> Option<String> { ... }
fn kind(&self) -> QueryKind { ... }
fn should_unpack_json(&self) -> bool { ... }
fn geofilter(&self) -> Option<GeoFilter> { ... }
}Expand description
Trait for query types that can render Redis Search query strings.
Required Methods
Sourcefn to_redis_query(&self) -> String
fn to_redis_query(&self) -> String
Builds a Redis Search query string.
Provided Methods
Sourcefn render(&self) -> QueryRender
fn render(&self) -> QueryRender
Builds the full query render, including search options and params.
Sourcefn params(&self) -> Vec<QueryParam>
fn params(&self) -> Vec<QueryParam>
Query parameters used with Redis PARAMS.
Sourcefn return_fields(&self) -> Vec<String>
fn return_fields(&self) -> Vec<String>
Return fields requested by the query.
Sourcefn limit(&self) -> Option<QueryLimit>
fn limit(&self) -> Option<QueryLimit>
Limit clause requested by the query.
Sourcefn no_content(&self) -> bool
fn no_content(&self) -> bool
Whether the query should use NOCONTENT.
Sourcefn should_unpack_json(&self) -> bool
fn should_unpack_json(&self) -> bool
Whether JSON search results should be unpacked into top-level fields when no explicit projection is requested.